==> libdatetime-locale-perl_1.35.orig.tar.gz: DateTime-Locale-1.35/share/yo.pl <==
{
  am_pm_abbreviated => [
    "\N{U+00c0}\N{U+00e1}r\N{U+1ecd}\N{U+0300}",
    "\N{U+1ecc}\N{U+0300}s\N{U+00e1}n",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "d MMM, E",
    MMMMEd => "d, MMMM E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "d/M/y, E",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM , y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "yo",
  date_format_full => "EEEE, d MMM y",
  date_format_long => "d MMM y",
  date_format_medium => "d MM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Aj",
    "\N{U+00cc}s\N{U+1eb9}\N{U+0301}g",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}r",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}b",
    "\N{U+1eb8}t",
    "\N{U+00c0}b\N{U+00e1}m",
    "\N{U+00c0}\N{U+00ec}k",
  ],
  day_format_narrow => [
    "A",
    "\N{U+00cc}",
    "\N{U+1ecc}",
    "\N{U+1ecc}",
    "\N{U+1eb8}",
    "\N{U+00c0}",
    "\N{U+00c0}",
  ],
  day_format_wide => [
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301} Aj\N{U+00e9}",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301} \N{U+00cc}s\N{U+1eb9}\N{U+0301}gun",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}r\N{U+00fa}",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}b\N{U+1ecd}",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301} \N{U+1eb8}t\N{U+00ec}",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301} \N{U+00c0}b\N{U+00e1}m\N{U+1eb9}\N{U+0301}ta",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301} \N{U+00c0}\N{U+00ec}k\N{U+00fa}",
  ],
  day_stand_alone_abbreviated => [
    "Aj",
    "\N{U+00cc}s\N{U+1eb9}\N{U+0301}g",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}r",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}b",
    "\N{U+1eb8}t",
    "\N{U+00c0}b\N{U+00e1}m",
    "\N{U+00c0}\N{U+00ec}k",
  ],
  day_stand_alone_narrow => [
    "A",
    "\N{U+00cc}",
    "\N{U+1ecc}",
    "\N{U+1ecc}",
    "\N{U+1eb8}",
    "\N{U+00c0}",
    "\N{U+00c0}",
  ],
  day_stand_alone_wide => [
    "Aj\N{U+00e9}",
    "\N{U+00cc}s\N{U+1eb9}\N{U+0301}gun",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}r\N{U+00fa}",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}b\N{U+1ecd}",
    "\N{U+1eb8}t\N{U+00ec}",
    "\N{U+00c0}b\N{U+00e1}m\N{U+1eb9}\N{U+0301}ta",
    "\N{U+00c0}\N{U+00ec}k\N{U+00fa}",
  ],
  era_abbreviated => [
    "BCE",
    "AD",
  ],
  era_narrow => [
    "BCE",
    "AD",
  ],
  era_wide => [
    "Saju Kristi",
    "Lehin Kristi",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Yoruba",
  month_format_abbreviated => [
    "\N{U+1e62}\N{U+1eb9}\N{U+0301}r",
    "\N{U+00c8}r\N{U+00e8}l",
    "\N{U+1eb8}r\N{U+1eb9}\N{U+0300}n",
    "\N{U+00cc}gb",
    "\N{U+1eb8}\N{U+0300}bi",
    "\N{U+00d2}k\N{U+00fa}",
    "Ag\N{U+1eb9}",
    "\N{U+00d2}g\N{U+00fa}",
    "Owe",
    "\N{U+1ecc}\N{U+0300}w\N{U+00e0}",
    "B\N{U+00e9}l",
    "\N{U+1ecc}\N{U+0300}p\N{U+1eb9}",
  ],
  month_format_narrow => [
    "S",
    "\N{U+00c8}",
    "\N{U+1eb8}",
    "\N{U+00cc}",
    "\N{U+1eb8}\N{U+0300}",
    "\N{U+00d2}",
    "A",
    "\N{U+00d2}",
    "O",
    "\N{U+1ecc}\N{U+0300}",
    "B",
    "\N{U+1ecc}\N{U+0300}",
  ],
  month_format_wide => [
    "O\N{U+1e63}\N{U+00f9} \N{U+1e62}\N{U+1eb9}\N{U+0301}r\N{U+1eb9}\N{U+0301}",
    "O\N{U+1e63}\N{U+00f9} \N{U+00c8}r\N{U+00e8}l\N{U+00e8}",
    "O\N{U+1e63}\N{U+00f9} \N{U+1eb8}r\N{U+1eb9}\N{U+0300}n\N{U+00e0}",
    "O\N{U+1e63}\N{U+00f9} \N{U+00cc}gb\N{U+00e9}",
    "O\N{U+1e63}\N{U+00f9} \N{U+1eb8}\N{U+0300}bibi",
    "O\N{U+1e63}\N{U+00f9} \N{U+00d2}k\N{U+00fa}du",
    "O\N{U+1e63}\N{U+00f9} Ag\N{U+1eb9}m\N{U+1ecd}",
    "O\N{U+1e63}\N{U+00f9} \N{U+00d2}g\N{U+00fa}n",
    "O\N{U+1e63}\N{U+00f9} Owewe",
    "O\N{U+1e63}\N{U+00f9} \N{U+1ecc}\N{U+0300}w\N{U+00e0}r\N{U+00e0}",
    "O\N{U+1e63}\N{U+00f9} B\N{U+00e9}l\N{U+00fa}",
    "O\N{U+1e63}\N{U+00f9} \N{U+1ecc}\N{U+0300}p\N{U+1eb9}\N{U+0300}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+1e62}\N{U+1eb9}\N{U+0301}",
    "\N{U+00c8}r",
    "\N{U+1eb8}r",
    "\N{U+00cc}g",
    "\N{U+1eb8}\N{U+0300}b",
    "\N{U+00d2}k",
    "Ag",
    "\N{U+00d2}g",
    "Ow",
    "\N{U+1ecc}\N{U+0300}w",
    "B\N{U+00e9}",
    "\N{U+1ecc}\N{U+0300}p",
  ],
  month_stand_alone_narrow => [
    "S",
    "\N{U+00c8}",
    "\N{U+1eb8}",
    "\N{U+00cc}",
    "\N{U+1eb8}\N{U+0300}",
    "\N{U+00d2}",
    "A",
    "\N{U+00d2}",
    "O",
    "\N{U+1ecc}\N{U+0300}",
    "B",
    "\N{U+1ecc}\N{U+0300}",
  ],
  month_stand_alone_wide => [
    "\N{U+1e62}\N{U+1eb9}\N{U+0301}r\N{U+1eb9}\N{U+0301}",
    "\N{U+00c8}r\N{U+00e8}l\N{U+00e8}",
    "\N{U+1eb8}r\N{U+1eb9}\N{U+0300}n\N{U+00e0}",
    "\N{U+00cc}gb\N{U+00e9}",
    "\N{U+1eb8}\N{U+0300}bibi",
    "\N{U+00d2}k\N{U+00fa}du",
    "Ag\N{U+1eb9}m\N{U+1ecd}",
    "\N{U+00d2}g\N{U+00fa}n",
    "Owewe",
    "\N{U+1ecc}\N{U+0300}w\N{U+00e0}r\N{U+00e0}",
    "B\N{U+00e9}l\N{U+00fa}",
    "\N{U+1ecc}\N{U+0300}p\N{U+1eb9}\N{U+0300}",
  ],
  name => "Yoruba",
  native_language => "\N{U+00c8}d\N{U+00e8} Yor\N{U+00f9}b\N{U+00e1}",
  native_name => "\N{U+00c8}d\N{U+00e8} Yor\N{U+00f9}b\N{U+00e1}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin k\N{U+00ed}n\N{U+00ed}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin Kej\N{U+00ec}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}ta",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}rin",
  ],
  quarter_format_narrow => [
    "k\N{U+00ed}n\N{U+00ed}",
    "Kej\N{U+00ec}",
    "K\N{U+1eb9}ta",
    "K\N{U+1eb9}in",
  ],
  quarter_format_wide => [
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin k\N{U+00ed}n\N{U+00ed}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin Kej\N{U+00ec}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}ta",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}rin",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin k\N{U+00ed}n\N{U+00ed}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin Kej\N{U+00ec}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}ta",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}rin",
  ],
  quarter_stand_alone_narrow => [
    "k\N{U+00ed}",
    "Ke",
    "K\N{U+1eb9}t",
    "K\N{U+1eb9}r",
  ],
  quarter_stand_alone_wide => [
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin k\N{U+00ed}n\N{U+00ed}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin Kej\N{U+00ec}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}ta",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}rin",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "H:mm:ss z",
  time_format_medium => "H:m:s",
  time_format_short => "H:m",
  variant => undef,
  version => 41,
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/yo.pl <==
{
  am_pm_abbreviated => [
    "\N{U+00c0}\N{U+00e1}r\N{U+1ecd}\N{U+0300}",
    "\N{U+1ecc}\N{U+0300}s\N{U+00e1}n",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "d/M/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "d MMM, E",
    MMMMEd => "d, MMMM E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "d/M/y, E",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM , y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "yo",
  date_format_full => "EEEE, d MMM y",
  date_format_long => "d MMM y",
  date_format_medium => "d MM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Aj",
    "\N{U+00cc}s\N{U+1eb9}\N{U+0301}g",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}r",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}b",
    "\N{U+1eb8}t",
    "\N{U+00c0}b\N{U+00e1}m",
    "\N{U+00c0}\N{U+00ec}k",
  ],
  day_format_narrow => [
    "A",
    "\N{U+00cc}",
    "\N{U+1ecc}",
    "\N{U+1ecc}",
    "\N{U+1eb8}",
    "\N{U+00c0}",
    "\N{U+00c0}",
  ],
  day_format_wide => [
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301} Aj\N{U+00e9}",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301} \N{U+00cc}s\N{U+1eb9}\N{U+0301}gun",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}r\N{U+00fa}",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}b\N{U+1ecd}",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301} \N{U+1eb8}t\N{U+00ec}",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301} \N{U+00c0}b\N{U+00e1}m\N{U+1eb9}\N{U+0301}ta",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301} \N{U+00c0}\N{U+00ec}k\N{U+00fa}",
  ],
  day_stand_alone_abbreviated => [
    "Aj",
    "\N{U+00cc}s\N{U+1eb9}\N{U+0301}g",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}r",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}b",
    "\N{U+1eb8}t",
    "\N{U+00c0}b\N{U+00e1}m",
    "\N{U+00c0}\N{U+00ec}k",
  ],
  day_stand_alone_narrow => [
    "A",
    "\N{U+00cc}",
    "\N{U+1ecc}",
    "\N{U+1ecc}",
    "\N{U+1eb8}",
    "\N{U+00c0}",
    "\N{U+00c0}",
  ],
  day_stand_alone_wide => [
    "Aj\N{U+00e9}",
    "\N{U+00cc}s\N{U+1eb9}\N{U+0301}gun",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}r\N{U+00fa}",
    "\N{U+1ecc}j\N{U+1ecd}\N{U+0301}b\N{U+1ecd}",
    "\N{U+1eb8}t\N{U+00ec}",
    "\N{U+00c0}b\N{U+00e1}m\N{U+1eb9}\N{U+0301}ta",
    "\N{U+00c0}\N{U+00ec}k\N{U+00fa}",
  ],
  era_abbreviated => [
    "BCE",
    "AD",
  ],
  era_narrow => [
    "BCE",
    "AD",
  ],
  era_wide => [
    "Saju Kristi",
    "Lehin Kristi",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Yoruba",
  month_format_abbreviated => [
    "\N{U+1e62}\N{U+1eb9}\N{U+0301}r",
    "\N{U+00c8}r\N{U+00e8}l",
    "\N{U+1eb8}r\N{U+1eb9}\N{U+0300}n",
    "\N{U+00cc}gb",
    "\N{U+1eb8}\N{U+0300}bi",
    "\N{U+00d2}k\N{U+00fa}",
    "Ag\N{U+1eb9}",
    "\N{U+00d2}g\N{U+00fa}",
    "Owe",
    "\N{U+1ecc}\N{U+0300}w\N{U+00e0}",
    "B\N{U+00e9}l",
    "\N{U+1ecc}\N{U+0300}p\N{U+1eb9}",
  ],
  month_format_narrow => [
    "S",
    "\N{U+00c8}",
    "\N{U+1eb8}",
    "\N{U+00cc}",
    "\N{U+1eb8}\N{U+0300}",
    "\N{U+00d2}",
    "A",
    "\N{U+00d2}",
    "O",
    "\N{U+1ecc}\N{U+0300}",
    "B",
    "\N{U+1ecc}\N{U+0300}",
  ],
  month_format_wide => [
    "O\N{U+1e63}\N{U+00f9} \N{U+1e62}\N{U+1eb9}\N{U+0301}r\N{U+1eb9}\N{U+0301}",
    "O\N{U+1e63}\N{U+00f9} \N{U+00c8}r\N{U+00e8}l\N{U+00e8}",
    "O\N{U+1e63}\N{U+00f9} \N{U+1eb8}r\N{U+1eb9}\N{U+0300}n\N{U+00e0}",
    "O\N{U+1e63}\N{U+00f9} \N{U+00cc}gb\N{U+00e9}",
    "O\N{U+1e63}\N{U+00f9} \N{U+1eb8}\N{U+0300}bibi",
    "O\N{U+1e63}\N{U+00f9} \N{U+00d2}k\N{U+00fa}du",
    "O\N{U+1e63}\N{U+00f9} Ag\N{U+1eb9}m\N{U+1ecd}",
    "O\N{U+1e63}\N{U+00f9} \N{U+00d2}g\N{U+00fa}n",
    "O\N{U+1e63}\N{U+00f9} Owewe",
    "O\N{U+1e63}\N{U+00f9} \N{U+1ecc}\N{U+0300}w\N{U+00e0}r\N{U+00e0}",
    "O\N{U+1e63}\N{U+00f9} B\N{U+00e9}l\N{U+00fa}",
    "O\N{U+1e63}\N{U+00f9} \N{U+1ecc}\N{U+0300}p\N{U+1eb9}\N{U+0300}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+1e62}\N{U+1eb9}\N{U+0301}",
    "\N{U+00c8}r",
    "\N{U+1eb8}r",
    "\N{U+00cc}g",
    "\N{U+1eb8}\N{U+0300}b",
    "\N{U+00d2}k",
    "Ag",
    "\N{U+00d2}g",
    "Ow",
    "\N{U+1ecc}\N{U+0300}w",
    "B\N{U+00e9}",
    "\N{U+1ecc}\N{U+0300}p",
  ],
  month_stand_alone_narrow => [
    "S",
    "\N{U+00c8}",
    "\N{U+1eb8}",
    "\N{U+00cc}",
    "\N{U+1eb8}\N{U+0300}",
    "\N{U+00d2}",
    "A",
    "\N{U+00d2}",
    "O",
    "\N{U+1ecc}\N{U+0300}",
    "B",
    "\N{U+1ecc}\N{U+0300}",
  ],
  month_stand_alone_wide => [
    "\N{U+1e62}\N{U+1eb9}\N{U+0301}r\N{U+1eb9}\N{U+0301}",
    "\N{U+00c8}r\N{U+00e8}l\N{U+00e8}",
    "\N{U+1eb8}r\N{U+1eb9}\N{U+0300}n\N{U+00e0}",
    "\N{U+00cc}gb\N{U+00e9}",
    "\N{U+1eb8}\N{U+0300}bibi",
    "\N{U+00d2}k\N{U+00fa}du",
    "Ag\N{U+1eb9}m\N{U+1ecd}",
    "\N{U+00d2}g\N{U+00fa}n",
    "Owewe",
    "\N{U+1ecc}\N{U+0300}w\N{U+00e0}r\N{U+00e0}",
    "B\N{U+00e9}l\N{U+00fa}",
    "\N{U+1ecc}\N{U+0300}p\N{U+1eb9}\N{U+0300}",
  ],
  name => "Yoruba",
  native_language => "\N{U+00c8}d\N{U+00e8} Yor\N{U+00f9}b\N{U+00e1}",
  native_name => "\N{U+00c8}d\N{U+00e8} Yor\N{U+00f9}b\N{U+00e1}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin k\N{U+00ed}n\N{U+00ed}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin Kej\N{U+00ec}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}ta",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}rin",
  ],
  quarter_format_narrow => [
    "k\N{U+00ed}n\N{U+00ed}",
    "Kej\N{U+00ec}",
    "K\N{U+1eb9}ta",
    "K\N{U+1eb9}in",
  ],
  quarter_format_wide => [
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin k\N{U+00ed}n\N{U+00ed}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin Kej\N{U+00ec}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}ta",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}rin",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin k\N{U+00ed}n\N{U+00ed}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin Kej\N{U+00ec}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}ta",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}rin",
  ],
  quarter_stand_alone_narrow => [
    "k\N{U+00ed}",
    "Ke",
    "K\N{U+1eb9}t",
    "K\N{U+1eb9}r",
  ],
  quarter_stand_alone_wide => [
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin k\N{U+00ed}n\N{U+00ed}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin Kej\N{U+00ec}",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}ta",
    "\N{U+00cc}d\N{U+00e1}m\N{U+1eb9}\N{U+0301}rin K\N{U+1eb9}rin",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "H:mm:ss z",
  time_format_medium => "H:m:s",
  time_format_short => "H:m",
  variant => undef,
  version => 42,
}
